@@ -1,22 +1,31 @@
-/*
- * BibTeX Converter
- * Copyright (C) 2010-2024 by Thomas Dreibholz
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
-
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Contact: thomas.dreibholz@gmail.com
- */
+// ==========================================================================
+//                ____  _ _   _____   __  ______
+//                | __ )(_) |_|_   _|__\ \/ / ___|___  _ ____   __
+//                |  _ \| | '_ \| |/ _ \  / |   / _ \| '_ \ \ / /
+//                | |_) | | |_) | |  __//  \ |__| (_) | | | \ V /
+//                |____/|_|_.__/|_|\___/_/\_\____\___/|_| |_|\_/
+//
+//                          ---  BibTeX Converter  ---
+//                   https://www.nntb.no/~dreibh/bibtexconv/
+// ==========================================================================
+//
+// BibTeX Converter
+// Copyright (C) 2010-2025 by Thomas Dreibholz
+//
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+//
+// Contact: thomas.dreibholz@gmail.com
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -362,21 +371,23 @@ unsigned int checkAllURLs(PublicationSet* publicationSet,
                                     char input[1024];
                                     if(fgets((char*)&input, sizeof(input) - 1, metaFH) != NULL) {
                                        // printf("IN=%s",input);
-                                       if(strncmp(input, "Pages:          ", 16) == 0) {
-                                          addOrUpdateChildNode(publication, "numpages", format("%u", atol((const char*)&input[16])).c_str());
+                                       if(strncmp(input, "Pages:", 6) == 0) {
+                                          addOrUpdateChildNode(publication, "numpages", format("%u", atol((const char*)&input[6])).c_str());
                                        }
-                                       else if(strncmp(input, "Keywords:       ", 16) == 0) {
+                                       else if(strncmp(input, "Keywords:", 9) == 0) {
                                           Node* keywords = findChildNode(publication, "keywords");
                                           if(keywords == NULL) {
                                              // If there are no "keywords", add "url.keywords".
                                              // They can be renamed manually after a check.
+                                             std::string keywords((const char*)&input[9]);
                                              addOrUpdateChildNode(publication, "url.keywords",
-                                                                  string2utf8(std::string((const char*)&input[16]), "~", "").c_str());
+                                                                  string2utf8(trim(keywords), "~", "").c_str());
                                           }
                                        }
-                                       else if(strncmp(input, "Page size:      ", 16) == 0) {
+                                       else if(strncmp(input, "Page size:", 10) == 0) {
+                                          std::string pagesize((const char*)&input[10]);
                                           addOrUpdateChildNode(publication, "url.pagesize",
-                                                               string2utf8(std::string((const char*)&input[16]), "~", "").c_str());
+                                                               string2utf8(trim(pagesize), "~", "").c_str());
                                        }
                                     }
                                  }
